Struct frame_metadata::RuntimeMetadataPrefixed
source · pub struct RuntimeMetadataPrefixed(pub u32, pub RuntimeMetadata);Expand description
Metadata prefixed by a u32 for reserved usage
Tuple Fields
0: u321: RuntimeMetadataTrait Implementations
sourceimpl Debug for RuntimeMetadataPrefixed
impl Debug for RuntimeMetadataPrefixed
sourceimpl Decode for RuntimeMetadataPrefixed
impl Decode for RuntimeMetadataPrefixed
sourceimpl Encode for RuntimeMetadataPrefixed
impl Encode for RuntimeMetadataPrefixed
sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy )
Convert self to a slice and append it to the destination.
sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
sourcefn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
fn using_encoded<R, F>(&self, f: F) -> Rwhere F: FnOnce(&[u8]) -> R,
Convert self to a slice and then invoke the given closure with it.
sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
sourceimpl From<RuntimeMetadataPrefixed> for Vec<u8>
impl From<RuntimeMetadataPrefixed> for Vec<u8>
sourcefn from(value: RuntimeMetadataPrefixed) -> Self
fn from(value: RuntimeMetadataPrefixed) -> Self
Converts to this type from the input type.
sourceimpl From<RuntimeMetadataV14> for RuntimeMetadataPrefixed
impl From<RuntimeMetadataV14> for RuntimeMetadataPrefixed
sourcefn from(metadata: RuntimeMetadataLastVersion) -> RuntimeMetadataPrefixed
fn from(metadata: RuntimeMetadataLastVersion) -> RuntimeMetadataPrefixed
Converts to this type from the input type.
sourceimpl PartialEq<RuntimeMetadataPrefixed> for RuntimeMetadataPrefixed
impl PartialEq<RuntimeMetadataPrefixed> for RuntimeMetadataPrefixed
sourcefn eq(&self, other: &RuntimeMetadataPrefixed) -> bool
fn eq(&self, other: &RuntimeMetadataPrefixed) -> bool
This method tests for
self and other values to be equal, and is used
by ==.